@@ -3,12 +3,11 @@ import json
 import subprocess
 import threading
 import time
-from typing import Union
 
 import urwid
 from opentrons.protocol_api import ProtocolContext
 
-import laser
+from ondine_laser_control import laser
 
 movement_distances = {"0": 0.1, "1": 1, "2": 10}
 movement_distance = 0.1
@@ -43,7 +42,7 @@ class StoppableThread(threading.Thread):
         return self._stop_event.is_set()
 
 
-watcher_thread: Union[StoppableThread, None] = None
+watcher_thread = None
 
 
 def set_button_as_kill_switch(protocol_to_use: ProtocolContext):
@@ -55,7 +54,7 @@ def set_button_as_kill_switch(protocol_to_use: ProtocolContext):
             if protocol_to_use._hw_manager.hardware._backend.gpio_chardev.read_button():
                 protocol_to_use._hw_manager.hardware.halt()
 
-    watcher_thread: StoppableThread = StoppableThread(target=button_watcher)
+    watcher_thread = StoppableThread(target=button_watcher)
     watcher_thread.start()
 
     def stop_watcher():
